@@ -1,7 +1,7 @@
 use crate::{
 	disassembler::{Bitness, Disassembler},
 	rules::{
-		is_base_pivot_head, is_gadget_head, is_gadget_tail, is_stack_pivot_head,
+		is_base_pivot_head, is_gadget_tail, is_rop_gadget_head, is_stack_pivot_head,
 		is_stack_pivot_tail,
 	},
 	sections::Section,
@@ -118,7 +118,7 @@ impl Gadget {
 		match self.instructions.as_slice() {
 			[] => false,
 			[t] => is_stack_pivot_tail(t),
-			[h @ .., _] => h.iter().any(|i| is_stack_pivot_head(i)),
+			[h @ .., _] => h.iter().any(is_stack_pivot_head),
 		}
 	}
 
@@ -126,7 +126,7 @@ impl Gadget {
 		match self.instructions.as_slice() {
 			[] => false,
 			[_] => false,
-			[h @ .., _] => h.iter().any(|i| is_base_pivot_head(i)),
+			[h @ .., _] => h.iter().any(is_base_pivot_head),
 		}
 	}
 
@@ -210,7 +210,7 @@ impl<'b> Iterator for GadgetIterator<'b, '_> {
 				}
 
 				let current = &self.disassembly.instructions[index];
-				match is_gadget_head(current, self.noisy) {
+				match is_rop_gadget_head(current, self.noisy) {
 					true => {
 						instructions.push(*current);
 						index += current.len()
